@@ -18,10 +18,9 @@ class CustomHelpFormatter(argparse.HelpFormatter):
         get_metavar = self._metavar_formatter(action, default_metavar)
         if action.nargs == argparse.ONE_OR_MORE:
             return "%s" % get_metavar(1)
-        else:
-            return super(CustomHelpFormatter, self)._format_args(
-                action, default_metavar
-            )
+        return super(CustomHelpFormatter, self)._format_args(
+            action, default_metavar
+        )
 
 def compute_args():
     """
@@ -39,7 +38,16 @@ def compute_args():
         Written by thib1984.""",
         formatter_class=CustomHelpFormatter,
     )
-
+    my_parser.add_argument(
+        "-n",
+        "--games",
+        metavar="X",
+        action="store",
+        type=int,
+        default=0,
+        choices=range(1, 1001),
+        help="batch mode : number games (in 1->1000)",
+    )  
     my_parser.add_argument(
         "-r",
         "--rules",
@@ -53,8 +61,8 @@ def compute_args():
         action="store",
         type=int,
         default=-1,
-        choices=range(0, 5),
-        help="black player is a bot with a level [X] (in 1->4)",
+        choices=range(0, 6),
+        help="black player is a bot with a level [X] (in 1->5)",
     )        
     my_parser.add_argument(
         "-w",
@@ -63,14 +71,14 @@ def compute_args():
         action="store",
         type=int,
         default=-1,
-        choices=range(0, 5),
-        help="white player is a bot with a level [X] (in 1->4)",
+        choices=range(0, 6),
+        help="white player is a bot with a level [X] (in 1->5)",
     )    
     my_parser.add_argument(
         "-a",
         "--auto",
         action="store_true",
-        help="auto mode. Don't ask for uncessary actions.",
+        help="auto mode. Don't ask for uncessary actions",
     )                     
     my_parser.add_argument(
         "-f",
@@ -82,8 +90,14 @@ def compute_args():
         "-v",
         "--verbose",
         action="store_true",
-        help="verbose mode. Use for debug.",
+        help="verbose mode. Use for debug",
     )
+    my_parser.add_argument(
+        "-s",
+        "--silent",
+        action="store_true",
+        help="silent mode. Use for batch mode",
+    )    
     my_parser.add_argument(
         "-u",
         "--update",
